#!/bin/bash

export COMPONENT_HASH=934853fc5cb89c4e4d42849295618b2a3ba3011b
PKG_VERSION=0.4.15+cdh6.3.0
FULL_VERSION=0.4.15-cdh6.3.0
BASE_VERSION=0.4.15
PKG_RELEASE=1279813
CDH_CUSTOMER_PATCH=p0
CDH_PARCEL_CUSTOM_VERSION=0.4.15+cdh6.3.0-1279813.xenial
